import { Component, OnInit, Input } from '@angular/core';
import { NgbActiveModal } from '@ng-bootstrap/ng-bootstrap';
import { WorkOrderService } from '../services/work-order.service'; 
import { WorkOrder } from '../models/work-order.model'; 
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { HttpClient } from '@angular/common/http';

@Component({
  selector: 'app-new-work-order-modal',
  standalone: true,
  templateUrl: './new-work-order-modal.component.html',
  styleUrls: ['./new-work-order-modal.component.css'],
  imports: [CommonModule, FormsModule]
})
export class NewWorkOrderModalComponent implements OnInit {
  @Input() technicians: any[] = []; 
  
  newWorkOrder: WorkOrder = {
    woNum: 0,
    email: '',
    contactName: '',
    contactNumber: '',
    problem: '',
    technician: null,
    technicianComments: '',
    dateReceived: '',
    status: 'Open',
    $id: '' 
  };

  selectedTechnicianId: number = 0;
  currentDate: string;
  technicianComments: string = '';  
  dateReceived: string = '';  
  contactName: string = '';  
  contactNumber: string = ''; 
  email: string = '';  
  problem: string = '';  
  status: string = 'Open';  

  constructor(
    private http: HttpClient,
    public activeModal: NgbActiveModal,
    private workOrderService: WorkOrderService
  ) {
    const today = new Date();
    this.currentDate = today.toISOString().split('T')[0]; 
  }
  
  isModalVisible = true;

  ngOnInit(): void {
    const today = new Date();
    this.currentDate = today.toISOString().split('T')[0];
    this.newWorkOrder.dateReceived = this.currentDate;
    this.getTechnicians();
  }

  getTechnicians() {
    this.http.get<any>('https://lc-code-test-api.azurewebsites.net/api/technicians') 
      .subscribe((data) => {
        if (data && data.$values) {
          this.technicians = data.$values; 
          console.log('Technicians:', this.technicians); 
        } else {
          console.error('Expected technicians array not found:', data);
        }
      }, error => {
        console.error('Error fetching technicians:', error);
      });
  }

  onSubmit() {
    if (!this.selectedTechnicianId) {
      console.error('Please select a technician.');
      return; 
    }
  
    const selectedTechnician = this.technicians.find(t => t.technicianID === this.selectedTechnicianId);
  
    const newWorkOrder = {
      contactName: this.contactName,
      contactNumber: this.contactNumber,
      email: this.email,
      problem: this.problem,
      technicianID: this.selectedTechnicianId,  
      technicianComments: this.technicianComments,
      dateReceived: this.dateReceived = new Date().toISOString().split('T')[0],
      status: this.status,
      technician: selectedTechnician 
    };
  
    console.log('Work Order to Submit:', newWorkOrder);
  
    this.workOrderService.createWorkOrder(newWorkOrder).subscribe(
      (response) => {
        console.log('Work order created successfully:', response);
        window.location.reload();
      },
      (error) => {
        console.error('Error creating work order:', error);
      }
    );
  }

  closeModal(): void {
    this.activeModal.dismiss('Cross click');
  }
}